@@ -1,9 +1,7 @@
 package Digital::Driver;
-BEGIN {
-  $Digital::Driver::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Module for new drivers
-$Digital::Driver::VERSION = '0.002';
+$Digital::Driver::VERSION = '0.003';
 use strict;
 use warnings;
 use Package::Stash;
@@ -66,7 +64,7 @@ Digital::Driver - Module for new drivers
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SUPPORT
 
@@ -76,12 +74,12 @@ IRC
 
 Repository
 
-  https://github.com/homehivelab/p5-digital
+  https://github.com/cindustries/perl-digital
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  https://github.com/homehivelab/p5-digital/issues
+  https://github.com/cindustries/perl-digital/issues
 
 =head1 AUTHOR
 
@@ -89,7 +87,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2020 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
