@@ -1,9 +1,7 @@
 package Digital::Role;
-BEGIN {
-  $Digital::Role::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Base role for Digital driver (positive integer input)
-$Digital::Role::VERSION = '0.002';
+$Digital::Role::VERSION = '0.003';
 use Moo::Role;
 use Carp qw( croak );
 
@@ -33,7 +31,7 @@ Digital::Role - Base role for Digital driver (positive integer input)
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SUPPORT
 
@@ -43,12 +41,12 @@ IRC
 
 Repository
 
-  https://github.com/homehivelab/p5-digital
+  https://github.com/cindustries/perl-digital
   Pull request and additional contributors are welcome
 
 Issue Tracker
 
-  https://github.com/homehivelab/p5-digital/issues
+  https://github.com/cindustries/perl-digital/issues
 
 =head1 AUTHOR
 
@@ -56,7 +54,7 @@ Torsten Raudssus <torsten@raudss.us>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Torsten Raudssus.
+This software is copyright (c) 2020 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
